#!/bin/bash
set -e # Para caso de erro

if [ $UID != 0 ]; then {
	echo "Este script deve ser executado como superusuario, root ou sudo";
	exit 1;
	}
fi

if ping www.backports.org -c1; then
	echo "deb http://www.backports.org/debian/ sarge-backports main" >> /etc/apt/sources.list
	else
	{ echo "Falha ao conectar backports.org/debian"; exit 1; }
fi

apt-get update || { echo "Falha ao atualizar o apt-get"; exit 1; }

apt-get install -y dialog debconf-utils

## Mudamos o debconf para critical, para que no sejam feitas perguntas desnecessrias.
debconf-set-selections ./arqs-conf/debconf.critical
## Fim da configurao do DebConf

BACKTITLE='Instalao do ExpressoLivre 1.2'
INTRO='
Bem-Vindo(a) a instalao do ExpressoLivre!

3 (trs) perguntas sero feitas a voc.
- Escolha uma senha.
- Escolha uma organizao.
- Escolha um domnio.

Com estas informaes o script poder
instalar e configurar o ExpressoLivre.
'
#.....................................................................
dialog --backtitle "$BACKTITLE" \
   --cr-wrap \
   --msgbox "$INTRO" \
   17 55 &&
#.....................................................................
LDAP_PWD=$( dialog --stdout --inputbox 'Digite uma senha:' 0 0 )
#.....................................................................
ORG=$( dialog --stdout --inputbox 'Digite uma organizao:(ex.: celepar)' 0 55 )
#.....................................................................
DOMAIN=$( dialog --stdout --inputbox 'Digite seu domnio:(ex.: '$ORG'.com.br)' 0 55 )

#.....................................................................
dialog --backtitle "$BACKTITLE" --cr-wrap --msgbox \
"A instalao dos pacotes necessrios para o ExpressoLivre comear agora." 10 65 &&
#.....................................................................	    

apt-get -t sarge-backports install -y lsb-base openssl ssl-cert
apt-get install -y apache2-mpm-prefork libapache2-mod-php5 apache2-common apache2-utils php5 php5-common php5-dev php5-gd php5-imap php5-ldap php5-pgsql php5-cgi php5-cli postgresql-8.1 postgresql-common postgresql-client-8.1 postgresql-client-common slapd ldap-utils db4.2-util cyrus-admin-2.2 cyrus-clients-2.2 cyrus-common-2.2 cyrus-doc-2.2 cyrus-imapd-2.2 libcyrus-imap-perl22 postfix postfix-ldap libsasl2 libsasl2-modules sasl2-bin nmap vim libmail-imapclient-perl libparse-recdescent-perl libterm-readkey-perl libterm-readline-perl-perl zip unzip graphviz || { echo "Impossvel continuar, erro no nome dos pacotes"; exit 1;}

############################################################################################
# GET VARs
LDAP_DN=`php ./arqs-conf/makedn.php $DOMAIN`
LDAP_DC=`php ./arqs-conf/makedc.php $DOMAIN`
LDAP_PWD_MD5=`slappasswd -v -s $LDAP_PWD -h {MD5}`
LDAP_PWD_MD5=`php ./arqs-conf/regexp.php $LDAP_PWD_MD5`
HEADER_PWD=`php ./arqs-conf/pass.php $LDAP_PWD`
############################################################################################
# POSTGRES
cp ./arqs-conf/etc/postgresql/8.1/main/postgresql.conf /etc/postgresql/8.1/main/
cp ./arqs-conf/etc/postgresql/8.1/main/pg_hba.conf /etc/postgresql/8.1/main/
/etc/init.d/postgresql-8.1 restart

su - postgres -c 'dropdb expresso'  || { echo "Banco expresso no existia. [OK]"; }
su - postgres -c 'createdb -E LATIN1 expresso'  || { echo "Problemas na criao do banco expresso. [Falhou]"; exit 1;}

sed -e "s/LDAP_DN/$LDAP_DN/g" -e "s/LDAP_PWD/$LDAP_PWD/g" -e "s/ORG/$ORG/g" -e "s/DOMAIN/$DOMAIN/g" ./arqs-conf/expresso.dump > /tmp/expresso.dump
/etc/init.d/postgresql-8.1 restart
su - postgres -c 'psql -f /tmp/expresso.dump expresso'
rm /tmp/expresso.dump

############################################################################################
# APACHE
# descomente para gerar o certificado para o https
#apache2-ssl-certificate;

a2enmod rewrite;

cp -r -p ../../../expresso/ /var/www/
cp ./arqs-conf/etc/apache2/apache2.conf /etc/apache2/
cp ./arqs-conf/etc/apache2/ports.conf /etc/apache2/
cp ./arqs-conf/etc/apache2/sites-available/default /etc/apache2/sites-available/
cp -r -p ./arqs-conf/etc/apache2/ssl/ /etc/apache2/

cp ./arqs-conf/etc/php5/apache2/php.ini /etc/php5/apache2/
mkdir /php_sessions/ || { echo "Diretrio j existe. [OK]"; }
chmod -R 777 /php_sessions/

/etc/init.d/apache2 restart

############################################################################################
# OPENLDAP
/etc/init.d/slapd stop
sed -e "s/LDAP_DN/$LDAP_DN/g" -e "s/LDAP_PWD_MD5/$LDAP_PWD_MD5/g" ./arqs-conf/etc/ldap/slapd.conf > /etc/ldap/slapd.conf
cp ./arqs-conf/etc/ldap/schema/* /etc/ldap/schema/
rm -rf /var/lib/ldap
mkdir /var/lib/ldap
/etc/init.d/slapd start

sleep 2
sed -e "s/LDAP_DN/$LDAP_DN/g" -e "s/LDAP_PWD_MD5/$LDAP_PWD_MD5/g" -e "s/ORG/$ORG/g" -e "s/DOMAIN/$DOMAIN/g" -e "s/LDAP_DC/$LDAP_DC/g" ./arqs-conf/expresso.ldif > /tmp/expresso.ldif

sleep 2
slapadd -v -l /tmp/expresso.ldif

sleep 2
/etc/init.d/slapd restart
rm /tmp/expresso.ldif

############################################################################################
# CYRUS
cp ./arqs-conf/etc/imapd.conf /etc/
cp ./arqs-conf/etc/cyrus.conf /etc/
sed -e "s/LDAP_DN/$LDAP_DN/g" ./arqs-conf/etc/saslauthd.conf > /etc/saslauthd.conf
cp ./arqs-conf/etc/default/saslauthd /etc/default/

cp -p ./arqs-conf/usr/bin/cyradm_expresso /usr/bin/

/etc/init.d/saslauthd restart
sleep 4
/etc/init.d/cyrus2.2 restart
sleep 4
./arqs-conf/cyrus.pl $LDAP_PWD

############################################################################################
# POSTFIX
sed -e "s/LDAP_DN/$LDAP_DN/g" -e "s/DOMAIN/$DOMAIN/g" ./arqs-conf/etc/postfix/main.cf > /etc/postfix/main.cf
sed -e "s/DOMAIN/$DOMAIN/g" ./arqs-conf/etc/postfix/expresso-dominios > /etc/postfix/expresso-dominios
adduser postfix mail
/etc/init.d/postfix restart
postmap /etc/postfix/expresso-dominios
echo "127.0.0.1		$DOMAIN" >> /etc/hosts
############################################################################################
# mkpasswd
mkdir /home/expressolivre || { echo "Diretrio j existe. [OK]"; }
cp ./arqs-conf/home/expressolivre/* /home/expressolivre/
chown -R www-data.www-data /home/expressolivre/
############################################################################################
# HEADER_INC_PHP
sed -e "s/HEADER_PWD/$HEADER_PWD/g" ./arqs-conf/header.inc.php > /var/www/expresso/header.inc.php
chown www-data.www-data /var/www/expresso/header.inc.php

############################################################################################
echo Acerta permissoes das pastas crls e temp em /var/www/expresso/seguranca:
chown www-data:www-data /var/www/expresso/seguranca/temp   
chown www-data:www-data /var/www/expresso/logs 
chown -R www-data:www-data /var/www/expresso/seguranca/crls
chown www-data.www-data /var/www/expresso/seguranca/crl_admin/crl_admin.py
chmod 755 /var/www/expresso/seguranca/temp                 
chmod 755 /var/www/expresso/seguranca/crls  
chmod 755 /var/www/expresso/seguranca/crl_admin/crl_admin.py

############################################################################################

## Mudamos o debconf para high, default do Debian Sarge.
debconf-set-selections ./arqs-conf/debconf.high
## Fim da configurao do DebConf

dialog --backtitle "$BACKTITLE" --cr-wrap --msgbox "FIM !! by JakJr (jakjr@celepar.pr.gov.br) www.expressolivre.org" 7 55 &&

echo '.'
